/*
---------------------------------------------------------------------
SINOMCU Copyright (C) 2018
---------------------------------------------------------------------
COMMON.h
V 1.0.0
By Jurgen Feng
2018.11.1
The file is ONLY for SINOMCU MC51F7004 product.
---------------------------------------------------------------------
NOTE: The file is distributed in the hope that it will be useful,
			but WITHOUT ANY WRRANTY! 
			Because of that, we strongly recommend you to keep up-date 
			file from our website or inquire us for a telephone support.
http://sinomcu.com
Telphone:+86-021-38682906
---------------------------------------------------------------------
All Rights Reserved
---------------------------------------------------------------------
*/
#ifndef __MC51F8124_COMMON_H_
#define __MC51F8124_COMMON_H_ 



/********************************************************************
* Includes
********************************************************************/
#include "MC51F8124.h"
#include <intrins.h> 

typedef enum {RESET = 0, SET = !RESET} flagstatus, ITstatus;

#define __I 	volatile const /* defines 'read only' permissions */
#define __O 	volatile /* defines 'write only' permissions */
#define __IO 	volatile /* defines 'read / write' permissions */
/********************************************************************
* Macros and Definitions
********************************************************************/
typedef bit                  	BIT;
typedef unsigned char        	UINT8;
typedef unsigned int          UINT16;
typedef unsigned long        	UINT32;

typedef unsigned char         	uint8_t;
typedef unsigned char         	uchar;
typedef unsigned char         	u8;
typedef unsigned int          	uint16_t;
typedef unsigned int          	uint;
typedef unsigned int          	u16;
typedef unsigned long         	uint32_t;
typedef unsigned long         	ulong;
typedef unsigned long	        	u32;

#define CBYTE ((unsigned char volatile code  *) 0)
#define DBYTE ((unsigned char volatile data  *) 0)
#define PBYTE ((unsigned char volatile pdata *) 0)
#define XBYTE ((unsigned char volatile xdata *) 0)

#define CWORD ((unsigned int volatile code  *) 0)
#define DWORD ((unsigned int volatile data  *) 0)
#define PWORD ((unsigned int volatile pdata *) 0)
#define XWORD ((unsigned int volatile xdata *) 0)

#define __I  volatile const /* defines 'read only' permissions */
#define __O  volatile /* defines 'write only' permissions */
#define __IO  volatile /* defines 'read / write' permissions */

#define NOP()					_nop_()	//  no operation 
#define	NVIC_SETPRIMASK()		EA=0	//  shut-down INTs
#define NVIC_RESETPRIMASK()		EA=1	// turn on INTs 


//16 --> 8 x 2
#define HIBYTE(v1)              ((UINT8)((v1)>>8))						// v1 is UINT16
#define LOBYTE(v1)              ((UINT8)((v1)&0xFF))
//8 x 2 --> 16
#define MAKEWORD(v1,v2)         ((((UINT16)(v1))<<8)+(UINT16)(v2))	// v1,v2 is UINT8
//8 x 4 --> 32
#define MAKELONG(v1,v2,v3,v4)   (UINT32)((v1<<32)+(v2<<16)+(v3<<8)+v4)  // v1,v2,v3,v4 is UINT8
//32 --> 16 x 2
#define YBYTE1(v1)              ((UINT16)((v1)>>16))                   // v1 is UINT32
#define YBYTE0(v1)              ((UINT16)((v1)&0xFFFF))
//32 --> 8 x 4
#define TBYTE3(v1)              ((UINT8)((v1)>>24))                    // v1 is UINT32
#define TBYTE2(v1)              ((UINT8)((v1)>>16))
#define TBYTE1(v1)              ((UINT8)((v1)>>8)) 
#define TBYTE0(v1)              ((UINT8)((v1)&0xFF))

#define SET_BIT0        		0x01
#define SET_BIT1        		0x02
#define SET_BIT2        		0x04
#define SET_BIT3        		0x08
#define SET_BIT4        		0x10
#define SET_BIT5        		0x20
#define SET_BIT6        		0x40
#define SET_BIT7        		0x80

#define CLR_BIT0        		0xFE
#define CLR_BIT1        		0xFD
#define CLR_BIT2        		0xFB
#define CLR_BIT3        		0xF7
#define CLR_BIT4        		0xEF
#define CLR_BIT5        		0xDF
#define CLR_BIT6        		0xBF
#define CLR_BIT7        		0x7F

#define FAIL            		1
#define PASS            		0

#define HI	            		1
#define LOW	            		0

#define ON	            		1
#define OFF	            		0

#define ENABLE    					1
#define DISABLE  						0

#define ERROR()					for(;;)					// endless loop for error
#define REG_CLR         0
#define CLR_WDT (WDTCR = 0x07)					// 喂狗，设置看门狗为最大溢出时间1024ms
//#if 0
#define UNLOCK_POWER_MODE		0x55					//  SLPCR = 0x55

#define SFR_SWITCH_ON()			_push_(DPS)				// save DPS				
#define SFR_SWITCH_OFF()		_pop_(DPS)				// restore DPS
#define SLK_SFR0()				SFRSL0=0				// SFR0 is selected
#define SLK_SFR1()				SFRSL0=1				// SFR1 is selected
#define USE_MUL16()				MUL16=1					// 16-bit hardware multiplier is used
#define NUS_MUL16()				MUL16=0					// 16-bit hardware multiplier is NOT used
#define USE_DIV16()				DIV16=1					// 16-bit hardware divider is used
#define NUS_DIV16()				MUL16=0					// 16-bit hardware divider is NOT used
#define SLK_DPTR()				SEL=0					// DPTR is selected
#define SLK_DPTR1()				SEL=1					// DPTR1 is selected

/*  MACRO  */ 
/*  SLPCR, 0x86H, SFR0  */  

/*  PCON, 0x87H, SFR0  */
#define SET_UART1EN()			PCON|=SET_BIT7			// PCON^7;
#define CLR_UART1EN()			PCON&=~SET_BIT7
//PCON^6;
//PCON^5;
#define SET_UART0EN()			PCON|=SET_BIT4			// PCON^4;
#define CLR_UART0EN()			PCON&=~SET_BIT4
#define SET_SMOD0()				PCON|=SET_BIT3			// PCON^3;
#define CLR_SMOD0()				PCON&=~SET_BIT3
#define SET_SSTAT0()			PCON|=SET_BIT2			// PCON^2;
#define CLR_SSTAT0()			PCON&=~SET_BIT2
#define SET_SLEEP()				PCON|=SET_BIT1			// PCON^1;  // protected by SLPCR & cleared by hardware
#define SET_STOP()				PCON|=SET_BIT0			// PCON^0;  // protected by SLPCR & cleared by hardware

/*  TMOD, 0x89H, SFR0  */
#define SET_GATE1()      		TMOD|=SET_BIT7			// TMOD^7;
#define CLR_GATE1()      		TMOD&=~SET_BIT7
#define SET_CT1()      			TMOD|=SET_BIT6      	// TMOD^6; 
#define CLR_CT1()      			TMOD&=~SET_BIT6 
#define SET_T1M1()      		TMOD|=SET_BIT5     		// TMOD^5; 
#define CLR_T1M1()      		TMOD&=~SET_BIT5
#define SET_T1M0()      		TMOD|=SET_BIT4			// TMOD^4; 
#define CLR_T1M0()      		TMOD&=~SET_BIT4
#define SET_GATE0()      		TMOD|=SET_BIT3			// TMOD^3; 
#define CLR_GATE0()      		TMOD&=~SET_BIT3
#define SET_CT0()      			TMOD|=SET_BIT2  	    // TMOD^2;
#define CLR_CT0()      			TMOD&=~SET_BIT2
#define SET_T0M1()      		TMOD|=SET_BIT1			// TMOD^1;
#define CLR_T0M1()      		TMOD&=~SET_BIT1
#define SET_T0M0()      		TMOD|=SET_BIT0			// TMOD^0;
#define CLR_T0M0()      		TMOD&=~SET_BIT0

/*  TL0, 0x8AH, SFR0  */

/*  TL1, 0x8BH, SFR0  */

/*  TH0, 0x8CH, SFR0  */

/*  TH1, 0x8DH, SFR0  */

/*  TCON1, 0x8EH, SFR0  */
#define SET_T1FS()				TCON1|=SET_BIT7			// TCON1^7;
#define CLR_T1FS()				TCON1&=~SET_BIT7
#define SET_T1OE()				TCON1|=SET_BIT6			// TCON1^6;
#define CLR_T1OE()				TCON1&=~SET_BIT6
#define SET_T1CKS1()			TCON1|=SET_BIT5			// TCON1^5;
#define CLR_T1CKS1()			TCON1&=~SET_BIT5
#define SET_T1CKS0()			TCON1|=SET_BIT4			// TCON1^4;
#define CLR_T1CKS0()			TCON1&=~SET_BIT4
#define SET_T0FS()				TCON1|=SET_BIT3			// TCON1^3;
#define CLR_T0FS()				TCON1&=~SET_BIT3
#define SET_T0OE()				TCON1|=SET_BIT2			// TCON1^2;
#define CLR_T0OE()				TCON1&=~SET_BIT2
#define SET_T0CKS1()			TCON1|=SET_BIT1			// TCON1^1;
#define CLR_T0CKS1()			TCON1&=~SET_BIT1
#define SET_T0CKS0()			TCON1|=SET_BIT0			// TCON1^0;
#define CLR_T0CKS0()			TCON1&=~SET_BIT0

/*  T3CR, 0x8FH, SFR0  */
#define SET_TR3()	      		T3CR|=SET_BIT7			// T3CR^7;
#define CLR_TR3()	      		T3CR&=~SET_BIT7
#define SET_CT3()   	  		T3CR|=SET_BIT6			// T3CR^6;
#define CLR_CT3()   	  		T3CR&=~SET_BIT6
#define SET_T3F()    	  		T3CR|=SET_BIT5			// T3CR^5;
#define CLR_T3F()    	  		T3CR&=~SET_BIT5 
//#define -      = T3CR^4; 
#define SET_T3EN()  	  		T3CR|=SET_BIT3			// T3CR^3;
#define CLR_T3EN()  	  		T3CR&=~SET_BIT3
#define SET_T3CKS2()     		T3CR|=SET_BIT2			// T3CR^2;
#define CLR_T3CKS2()     		T3CR&=~SET_BIT2
#define SET_T3CKS1()     		T3CR|=SET_BIT1			// T3CR^1;
#define CLR_T3CKS1()     		T3CR&=~SET_BIT1 
#define SET_T3CKS0()     		T3CR|=SET_BIT0			// T3CR^0;
#define CLR_T3CKS0()     		T3CR&=~SET_BIT0

/*  P1MOD0, 0x91H, SFR0  */

/*  P1MOD1, 0x92H, SFR0  */

/*  P1PU, 0x93H, SFR0  */

/*  P1S, 0x94H, SFR0  */

/*  TL3, 0x96H, SFR0  */

/*  TH3, 0x97H, SFR0  */

/*  SBUF, 0x99H, SFR0  */

/*  SADDR, 0x9AH, SFR0  */

/*  SADEN, 0x9BH, SFR0  */

/*  SCON_1, 0x9CH, SFR0  */
#define SET_SM0_1()      		SCON_1|=SET_BIT7		// SCON_1^7;
#define CLR_SM0_1()      		SCON_1&=~SET_BIT7
#define SET_SM1_1()				SCON_1|=SET_BIT6		//  SCON_1^6;
#define CLR_SM1_1()				SCON_1&=~SET_BIT6
#define SET_SM2_1()				SCON_1|=SET_BIT5		//  SCON_1^5;
#define CLR_SM2_1()				SCON_1&=~SET_BIT5
#define SET_REN_1()				SCON_1|=SET_BIT4		//  SCON_1^4;
#define CLR_REN_1()				SCON_1&=~SET_BIT4
#define SET_TB8_1()				SCON_1|=SET_BIT3		//  SCON_1^3;
#define CLR_TB8_1()				SCON_1&=~SET_BIT3
#define SET_RB8_1()				SCON_1|=SET_BIT2		//  SCON_1^2;
#define CLR_RB8_1()				SCON_1&=~SET_BIT2
#define SET_TI_1()				SCON_1|=SET_BIT1		//  SCON_1^1;
#define CLR_TI_1()				SCON_1&=~SET_BIT1
#define SET_RI_1()				SCON_1|=SET_BIT0		//  SCON_1^0;
#define CLR_RI_1()				SCON_1&=~SET_BIT0

/*  SBUF_1, 0x9DH, SFR0  */

/*  P2MOD0, 0xA1H, SFR0  */

/*  P2MOD1, 0xA2H, SFR0  */

/*  P2PU, 0xA3H, SFR0  */

/*  P2S, 0xA4H, SFR0  */

#define CLR_SACK()         IICCR &=~SET_BIT3  

/*  IE1, 0xA9H, SFR0  */
#define SET_CRCIE()      		IE1|=SET_BIT7			// IE1^7;
#define CLR_CRCIE()      		IE1&=~SET_BIT7
//#define -      	= IE1^6;
#define SET_PWM1FBIE()			IE1|=SET_BIT5			// IE1^5;
#define CLR_PWM1FBIE()			IE1&=~SET_BIT5
#define SET_PWM0IE()			IE1|=SET_BIT4			// IE1^4;
#define CLR_PWM0IE()			IE1&=~SET_BIT4
#define SET_UART1IE()			IE1|=SET_BIT3			// IE1^3;
#define CLR_UART1IE()			IE1&=~SET_BIT3
#define SET_PWM1IE()   			IE1|=SET_BIT2			// IE1^2;
#define CLR_PWM1IE()   			IE1&=~SET_BIT2
#define SET_T3IE()       		IE1|=SET_BIT1			// IE1^1;
#define CLR_T3IE()       		IE1&=~SET_BIT1
#define SET_T2IE()	      		IE1|=SET_BIT0			// IE1^0;
#define CLR_T2IE()	      		IE1&=~SET_BIT0

/*  EXTIS1, 0xABH, SFR0  */
//#define -        = EXTIS1^7;
#define SET_EXT1IF4()     		EXTIS1|=SET_BIT6		// EXTIS1^6;
#define CLR_EXT1IF4()     		EXTIS1&=~SET_BIT6
#define SET_EXT1IF3()			EXTIS1|=SET_BIT5		//  EXTIS1^5;
#define CLR_EXT1IF3()			EXTIS1&=~SET_BIT5
#define SET_EXT1IF2()			EXTIS1|=SET_BIT4		//  EXTIS1^4;
#define CLR_EXT1IF2()			EXTIS1&=~SET_BIT4
#define SET_EXT1IF1()			EXTIS1|=SET_BIT3		//  EXTIS1^3;
#define CLR_EXT1IF1()			EXTIS1&=~SET_BIT3
#define SET_EXT1IF0()			EXTIS1|=SET_BIT2		//  EXTIS1^2;
#define CLR_EXT1IF0()			EXTIS1&=~SET_BIT2
#define SET_EXT1IS1()			EXTIS1|=SET_BIT1		//  EXTIS1^1;
#define CLR_EXT1IS1()			EXTIS1&=~SET_BIT1
#define SET_EXT1IS0()			EXTIS1|=SET_BIT0		//  EXTIS1^0;
#define CLR_EXT1IS0()			EXTIS1&=~SET_BIT0


/*  EXTEN1, 0xABH, SFR1  */
//#define -	      = EXTEN1^7;
#define SET_EXT1EN4()    		EXTEN1|=SET_BIT6		// EXTEN1^6;
#define CLR_EXT1EN4()    		EXTEN1&=~SET_BIT6
#define SET_EXT1EN3()    		EXTEN1|=SET_BIT5		// EXTEN1^5;
#define CLR_EXT1EN3()    		EXTEN1&=~SET_BIT5
#define SET_EXT1EN2()    		EXTEN1|=SET_BIT4		// EXTEN1^4;
#define CLR_EXT1EN2()    		EXTEN1&=~SET_BIT4
#define SET_EXT1EN1()    		EXTEN1|=SET_BIT3		// EXTEN1^3;
#define CLR_EXT1EN1()    		EXTEN1&=~SET_BIT3
#define SET_EXT1EN0()    		EXTEN1|=SET_BIT2		// EXTEN1^2;
#define CLR_EXT1EN0()    		EXTEN1&=~SET_BIT2
//#define -        = EXTEN1^1;
#define SET_EXT1A()      		EXTEN1|=SET_BIT0		// EXTEN1^0;
#define CLR_EXT1A()      		EXTEN1&=~SET_BIT0

/*  EXTIS, 0xACH, SFR0  */
//#define -        = EXTIS^7;
#define SET_EXT0IF4()     		EXTIS|=SET_BIT6			// EXTIS^6;
#define CLR_EXT0IF4()     		EXTIS&=~SET_BIT6
#define SET_EXT0IF3()     		EXTIS|=SET_BIT5			// EXTIS^5;
#define CLR_EXT0IF3()     		EXTIS&=~SET_BIT5
#define SET_EXT0IF2()	 		EXTIS|=SET_BIT4			// EXTIS^4;
#define CLR_EXT0IF2()	 		EXTIS&=~SET_BIT4
#define SET_EXT0IF1()	 		EXTIS|=SET_BIT3			// EXTIS^3;
#define CLR_EXT0IF1()	 		EXTIS&=~SET_BIT3
#define SET_EXT0IF0()     		EXTIS|=SET_BIT2			// EXTIS^2;
#define CLR_EXT0IF0()     		EXTIS&=~SET_BIT2
#define SET_EXT0IS1()			EXTIS|=SET_BIT1			//  EXTIS^1;
#define CLR_EXT0IS1()			EXTIS&=~SET_BIT1
#define SET_EXT0IS0()			EXTIS|=SET_BIT0			//  EXTIS^0;
#define CLR_EXT0IS0()			EXTIS&=~SET_BIT0


/*  EXTEN, 0xACH, SFR1  */
//#define -	      = EXTEN^7;
#define SET_EXT0EN4()    		EXTEN|=SET_BIT6			// EXTEN^6;
#define CLR_EXT0EN4()    		EXTEN&=~SET_BIT6
#define SET_EXT0EN3()    		EXTEN|=SET_BIT5			// EXTEN^5;
#define CLR_EXT0EN3()    		EXTEN&=~SET_BIT5
#define SET_EXT0EN2()    		EXTEN|=SET_BIT4			// EXTEN^4;
#define CLR_EXT0EN2()    		EXTEN&=~SET_BIT4
#define SET_EXT0EN1()    		EXTEN|=SET_BIT3			// EXTEN^3;
#define CLR_EXT0EN1()    		EXTEN&=~SET_BIT3
#define SET_EXT0EN0()    		EXTEN|=SET_BIT2			// EXTEN^2;
#define CLR_EXT0EN0()    		EXTEN&=~SET_BIT2
//#define -        = EXTEN^1;
#define SET_EXT0A()      		EXTEN|=SET_BIT0			// EXTEN^0;
#define CLR_EXT0A()      		EXTEN&=~SET_BIT0

/*  SPCON, 0xADH, SFR0  */
#define SET_DIR()        		SPCON|=SET_BIT7			// SPCON^7;
#define CLR_DIR()        		SPCON&=~SET_BIT7
#define SET_MSTR()				SPCON|=SET_BIT6			// SPCON^6;
#define CLR_MSTR()				SPCON&=~SET_BIT6
#define SET_CPHA()				SPCON|=SET_BIT5			// SPCON^5;
#define CLR_CPHA()				SPCON&=~SET_BIT5
#define SET_CPOL()		    	SPCON|=SET_BIT4			// SPCON^4;
#define CLR_CPOL()		    	SPCON&=~SET_BIT4
#define SET_SSDIS()				SPCON|=SET_BIT3			// SPCON^3;
#define CLR_SSDIS()				SPCON&=~SET_BIT3
#define SET_SPR2()				SPCON|=SET_BIT2			// SPCON^2;
#define CLR_SPR2()				SPCON&=~SET_BIT2
#define SET_SPR1()				SPCON|=SET_BIT1			// SPCON^1;
#define CLR_SPR1()				SPCON&=~SET_BIT1
#define SET_SPR0()	      		SPCON|=SET_BIT0			// SPCON^0;
#define CLR_SPR0()	      		SPCON&=~SET_BIT0

/*  SPSTA, 0xAEH, SFR0  */
#define SET_SPEN()        		SPSTA|=SET_BIT7			// SPSTA^7;
#define CLR_SPEN()        		SPSTA&=~SET_BIT7
#define SET_SPIF()	      		SPSTA|=SET_BIT6			// SPSTA^6;
#define CLR_SPIF()	      		SPSTA&=~SET_BIT6
#define SET_MODF()				SPSTA|=SET_BIT5			// SPSTA^5;
#define CLR_MODF()				SPSTA&=~SET_BIT5
#define SET_WCOL()		    	SPSTA|=SET_BIT4			// SPSTA^4;
#define CLR_WCOL()		    	SPSTA&=~SET_BIT4
#define SET_SPIOV()	    		SPSTA|=SET_BIT3			// SPSTA^3;
#define CLR_SPIOV()	    		SPSTA&=~SET_BIT3
//#define 	  	    	SPSTA|=SET_BIT2						// SPSTA^2;
//#define       		SPSTA|=SET_BIT1						// SPSTA^1;
//#define 	      		SPSTA|=SET_BIT0						// SPSTA^0;

/*  SPDAT, 0xAFH, SFR0  */

/*  IPH, 0xB9H, SFR0  */
//#define -        = IP^7;
#define SET_ADCIPH()    		IPH|=SET_BIT6			// IP^6;
#define CLR_ADCIPH()    		IPH&=~SET_BIT6
#define SET_SPIIPH()      		IP1|=SET_BIT5			// IP1^5;
#define CLR_SPIIPH()      		IP1&=~SET_BIT5
#define SET_UART0IPH()   		IPH|=SET_BIT4			// IP^4;
#define CLR_UART0IPH()   		IPH&=~SET_BIT4
#define SET_T1IPH()      		IPH|=SET_BIT3			// IP^3;
#define CLR_T1IPH()      		IPH&=~SET_BIT3
#define SET_EXT1IPH()    		IPH|=SET_BIT2			// IP^2;
#define CLR_EXT1IPH()    		IPH&=~SET_BIT2
#define SET_T0IPH()	    		IPH|=SET_BIT1			// IP^1;
#define CLR_T0IPH()	    		IPH&=~SET_BIT1
#define SET_EXT0IPH()    		IPH|=SET_BIT0			// IP^0;
#define CLR_EXT0IPH()    		IPH&=~SET_BIT0

/*  IP1, 0xBAH, SFR0  */
#define SET_CRCIPL()    		IP1|=SET_BIT7			// IP1^7;
#define CLR_CRCIPL()    		IP1&=~SET_BIT7
//#define SET_()    		IP1|=SET_BIT6					// IP1^2;
//#define CLR_()    		IP1&=~SET_BIT6
#define SET_PWM1FBIPL()    		IP1|=SET_BIT5			// IP1^6;
#define CLR_PWM1FBIPL()    		IP1&=~SET_BIT5
#define SET_PWM0IPL()   		IP1|=SET_BIT4			// IP1^4;
#define CLR_PWM0IPL()   		IP1&=~SET_BIT4
#define SET_UART1IPL()   		IPH|=SET_BIT3			// IP^3;
#define CLR_UART1IPL()   		IPH&=~SET_BIT3
#define SET_PWM1IPL()   		IP1|=SET_BIT2			// IP1^3;
#define CLR_PWM1IPL()   		IP1&=~SET_BIT2
#define SET_T3IPL()	    		IP1|=SET_BIT1			// IP1^1;
#define CLR_T3IPL()	    		IP1&=~SET_BIT1
#define SET_T2IPL()    			IP1|=SET_BIT0			// IP1^0;
#define CLR_T2IPL()    			IP1&=~SET_BIT0

/*  IPH1, 0xBBH, SFR0  */
#define SET_CRCIPH()    		IPH1|=SET_BIT7			// IPH1^7;
#define CLR_CRCIPH()    		IPH1&=~SET_BIT7
//#define SET_()    		IPH1|=SET_BIT6					// IPH1^6;
//#define CLR_()    		IPH1&=~SET_BIT6
#define SET_PWM1FBIPH()    		IPH1|=SET_BIT5			// IPH1^5;
#define CLR_PWM1FBIPH()    		IPH1&=~SET_BIT5
#define SET_PWM0IPH()   		IPH1|=SET_BIT4			// IPH1^4;
#define CLR_PWM0IPH()   		IPH1&=~SET_BIT4
#define SET_UART1IPH()     		IPH1|=SET_BIT3			// IPH1^3;
#define CLR_UART1IPH()     		IPH1&=~SET_BIT3
#define SET_PWM1IPH()   		IPH1|=SET_BIT2			// IPH1^2;
#define CLR_PWM1IPH()   		IPH1&=~SET_BIT2
#define SET_T3IPH()	    		IPH1|=SET_BIT1			// IPH1^1;
#define CLR_T3IPH()	    		IPH1&=~SET_BIT1
#define SET_T2IPH()    			IPH1|=SET_BIT0			// IPH1^0;
#define CLR_T2IPH()    			IPH1&=~SET_BIT0

/*  P0MOOD0, 0xC1H, SFR0  */

/*  CRCCR, 0xD1H, SFR0  */
#define SET_CRCEN()    		CRCCR|=SET_BIT7				// CRCCR^7;
#define CLR_CRCEN()    		CRCCR&=~SET_BIT7
//#define SET_	    		CRCCR|=SET_BIT6					// CRCCR^6;
//#define CLR_	    		CRCCR&=~SET_BIT6
#define SET_CRCIF()   		CRCCR|=SET_BIT5				// CRCCR^5;
#define CLR_CRCIF()   		CRCCR&=~SET_BIT5
#define SET_CRCST()   		CRCCR|=SET_BIT4				// CRCCR^4;
#define CLR_CRCST()   		CRCCR&=~SET_BIT4
#define SET_CRCMD()    		CRCCR|=SET_BIT3				// CRCCR^3;
#define CLR_CRCMD()    		CRCCR&=~SET_BIT3
#define SET_CRCLCT()   		CRCCR|=SET_BIT2				// CRCCR^2;
#define CLR_CRCLCT()   		CRCCR&=~SET_BIT2
#define SET_CRCBIT()   		CRCCR|=SET_BIT1				// CRCCR^1;
#define CLR_CRCBIT()   		CRCCR&=~SET_BIT1
#define SET_CRCENC()		CRCCR|=SET_BIT0				// CRCCR^0;
#define CLR_CRCENC()		CRCCR&=~SET_BIT0

/*  CRCL, 0xC2H, SFR1  */


/*  P0PU, 0xC3H, SFR0  */
/*  CRCH, 0xC3H, SFR1  */

/*  P0S, 0xC4H, SFR0  */
/*  CRCSTL, 0xC4H, SFR1  */

/*  CRCSTH, 0xC5H, SFR1  */

/*  CRCEDL, 0xC6H, SFR1  */

/*  CRCEDH, 0xC7H, SFR1  */

/*  T2MOD, 0xC9H, SFR0  */
#define SET_LD2EN()    		T2MOD|=SET_BIT7				// T2MOD^7;
#define CLR_LD2EN()    		T2MOD&=~SET_BIT7
#define SET_T2CKS2()   		T2MOD|=SET_BIT6				// T2MOD^6;
#define CLR_T2CKS2()   		T2MOD&=~SET_BIT6
#define SET_T2CKS1()   		T2MOD|=SET_BIT5				// T2MOD^5;
#define CLR_T2CKS1()   		T2MOD&=~SET_BIT5
#define SET_T2CKS0()    	T2MOD|=SET_BIT4				// T2MOD^4;
#define CLR_T2CKS0()    	T2MOD&=~SET_BIT4
#define SET_T2OE()    		T2MOD|=SET_BIT3				// T2MOD^3;
#define CLR_T2OE()	   		T2MOD&=~SET_BIT3
#define SET_T2SL1()   		T2MOD|=SET_BIT2				// T2MOD^2;
#define CLR_T2SL1()   		T2MOD&=~SET_BIT2
#define SET_T2SL0()   		T2MOD|=SET_BIT1				// T2MOD^1;
#define CLR_T2SL0()   		T2MOD&=~SET_BIT1
#define SET_DC2EN()			T2MOD|=SET_BIT0				// T2MOD^0;
#define CLR_DC2EN()			T2MOD&=~SET_BIT0

/*  RCAPL2, 0xCBH, SFR0  */

/*  RCAPH2, 0xCAH, SFR0  */

/*  TL2, 0xCCH, SFR0  */

/*  TH2, 0xCDH, SFR0  */

/*  T2CON1, 0xCEH, SFR0  */
#define SET_CM2ON()    		T2CON1|=SET_BIT7			// T2CON1^7;
#define CLR_CM2ON()    		T2CON1&=~SET_BIT7
#define SET_CM2()	    	T2CON1|=SET_BIT6			// T2CON1^6;
#define CLR_CM2()	    	T2CON1&=~SET_BIT6
#define SET_BR2EN()   		T2CON1|=SET_BIT5			// T2CON1^5;
#define CLR_BR2EN()   		T2CON1&=~SET_BIT5
#define SET_RCLKU1()   		T2CON1|=SET_BIT4			// T2CON1^4;
#define CLR_RCLKU1()   		T2CON1&=~SET_BIT4
#define SET_TCLKU1()    	T2CON1|=SET_BIT3			// T2CON1^3;
#define CLR_TCLKU1()    	T2CON1&=~SET_BIT3
#define SET_EX2SL()   		T2CON1|=SET_BIT2			// T2CON1^2;
#define CLR_EX2SL()   		T2CON1&=~SET_BIT2
// #define SET_   		T2CON1|=SET_BIT1				// T2CON1^1;
// #define CLR_   		T2CON1&=~SET_BIT1
#define SET_T2EN()			T2CON1|=SET_BIT0			// T2CON1^0;
#define CLR_T2EN()			T2CON1&=~SET_BIT0

/*  WDTCR, 0xCFH, SFR0  */
//#define SET_()    		WDTCR|=SET_BIT7				// WDTCR^7;
//#define CLR_()    		WDTCR&=~SET_BIT7
//#define SET_	    		WDTCR|=SET_BIT6				// WDTCR^6;
//#define CLR_	    		WDTCR&=~SET_BIT6
//#define SET_()   		WDTCR|=SET_BIT5				// WDTCR^5;
//#define CLR_()   		WDTCR&=~SET_BIT5
//#define SET_()   		WDTCR|=SET_BIT4				// WDTCR^4;
//#define CLR_()   		WDTCR&=~SET_BIT4
//#define SET_()    		WDTCR|=SET_BIT3				// WDTCR^3;
//#define CLR_()    		WDTCR&=~SET_BIT3
#define SET_WDTOT2()   		WDTCR|=SET_BIT2				// WDTCR^2;
#define CLR_WDTOT2()   		WDTCR&=~SET_BIT2
#define SET_WDTOT1()   		WDTCR|=SET_BIT1				// WDTCR^1;
#define CLR_WDTOT1()   		WDTCR&=~SET_BIT1
#define SET_WDTOT0()		WDTCR|=SET_BIT0				// WDTCR^0;
#define CLR_WDTOT0()		WDTCR&=~SET_BIT0

/*  LCDCR0, 0xD9H, SFR0  */
#define SET_LCDEN()    		LCDCR0|=SET_BIT7			// LCDCR0^7;
#define CLR_LCDEN()    		LCDCR0&=~SET_BIT7
#define SET_LCDMS()	    	LCDCR0|=SET_BIT6			// LCDCR0^6;
#define CLR_LCDMS()	    	LCDCR0&=~SET_BIT6
//#define SET_()   		LCDCR0|=SET_BIT5				// LCDCR0^5;
//#define CLR_()   		LCDCR0&=~SET_BIT5
//#define SET_()   		LCDCR0|=SET_BIT4				// LCDCR0^4;
//#define CLR_()   		LCDCR0&=~SET_BIT4
//#define SET_()    		LCDCR0|=SET_BIT3				// LCDCR0^3;
//#define CLR_()    		LCDCR0&=~SET_BIT3
//#define SET_()   		LCDCR0|=SET_BIT2				// LCDCR0^2;
//#define CLR_()   		LCDCR0&=~SET_BIT2
//#define SET_()   		LCDCR0|=SET_BIT1				// LCDCR0^1;
//#define CLR_()   		LCDCR0&=~SET_BIT1
//#define SET_()			LCDCR0|=SET_BIT0				// LCDCR0^0;
//#define CLR_()			LCDCR0&=~SET_BIT0


/*  LCDSW, 0xDAH, SFR0  */
#define SET_COM7EN()    		LCDSW|=SET_BIT7			// LCDSW^7;
#define CLR_COM7EN()    		LCDSW&=~SET_BIT7
#define SET_COM6EN()	    	LCDSW|=SET_BIT6			// LCDSW^6;
#define CLR_COM6EN()	    	LCDSW&=~SET_BIT6
#define SET_COM5EN()   	  	LCDSW|=SET_BIT5				// LCDSW^5;
#define CLR_COM5EN()   	  	LCDSW&=~SET_BIT5
#define SET_COM4EN()   	  	LCDSW|=SET_BIT4			// LCDSW^4;
#define CLR_COM4EN()   	  	LCDSW&=~SET_BIT4
#define SET_COM3EN()    		LCDSW|=SET_BIT3			// LCDSW^3;
#define CLR_COM3EN()    		LCDSW&=~SET_BIT3
#define SET_COM2EN()   	  	LCDSW|=SET_BIT2			// LCDSW^2;
#define CLR_COM2EN()   	  	LCDSW&=~SET_BIT2
#define SET_COM1EN()   	  	LCDSW|=SET_BIT1			// LCDSW^1;
#define CLR_COM1EN()   	  	LCDSW&=~SET_BIT1
#define SET_COM0EN()			  LCDSW|=SET_BIT0			// LCDSW^0;
#define CLR_COM0EN()			  LCDSW&=~SET_BIT0

/*  LCDSW1, 0xDBH, SFR0  */
#define SET_COM15EN()    		LCDSW1|=SET_BIT7			// LCDSW^7;
#define CLR_COM15EN()    		LCDSW1&=~SET_BIT7
#define SET_COM14EN()	    	LCDSW1|=SET_BIT6			// LCDSW^6;
#define CLR_COM14EN()	    	LCDSW1&=~SET_BIT6
#define SET_COM13EN()   	  LCDSW1|=SET_BIT5				// LCDSW^5;
#define CLR_COM13EN()   	  LCDSW1&=~SET_BIT5
#define SET_COM12EN()     	LCDSW1|=SET_BIT4			// LCDSW^4;
#define CLR_COM12EN()   	  LCDSW1&=~SET_BIT4
#define SET_COM11EN()    		LCDSW1|=SET_BIT3			// LCDSW^3;
#define CLR_COM11EN()    		LCDSW1&=~SET_BIT3
#define SET_COM10EN()   		LCDSW1|=SET_BIT2			// LCDSW^2;
#define CLR_COM10EN()   		LCDSW1&=~SET_BIT2
#define SET_COM9EN()   	   	LCDSW1|=SET_BIT1			// LCDSW^1;
#define CLR_COM9EN()     		LCDSW1&=~SET_BIT1
#define SET_COM8EN()			  LCDSW1|=SET_BIT0			// LCDSW^0;
#define CLR_COM8EN()			  LCDSW1&=~SET_BIT0
/*  LCDSW2, 0xDCH, SFR0  */
#define SET_COM23EN()    		LCDSW2|=SET_BIT7			// LCDSW^7;
#define CLR_COM23EN()    		LCDSW2&=~SET_BIT7
#define SET_COM22EN()	    	LCDSW2|=SET_BIT6			// LCDSW^6;
#define CLR_COM22EN()	    	LCDSW2&=~SET_BIT6
#define SET_COM21EN()   	  LCDSW2|=SET_BIT5				// LCDSW^5;
#define CLR_COM21EN()   	  LCDSW2&=~SET_BIT5
#define SET_COM20EN()     	LCDSW2|=SET_BIT4			// LCDSW^4;
#define CLR_COM20EN()   	  LCDSW2&=~SET_BIT4
#define SET_COM19EN()    		LCDSW2|=SET_BIT3			// LCDSW^3;
#define CLR_COM19EN()    		LCDSW2&=~SET_BIT3
#define SET_COM18EN()   		LCDSW2|=SET_BIT2			// LCDSW^2;
#define CLR_COM18EN()   		LCDSW2&=~SET_BIT2
#define SET_COM17EN()   	   	LCDSW2|=SET_BIT1			// LCDSW^1;
#define CLR_COM17EN()     		LCDSW2&=~SET_BIT1
#define SET_COM16EN()			  LCDSW2|=SET_BIT0			// LCDSW^0;
#define CLR_COM16EN()			  LCDSW2&=~SET_BIT0
/*  PWM0CR, 0xDDH, SFR0  */
#define SET_PWM0EN()    		PWM0CR|=SET_BIT7		// PWM0CR^7;
#define CLR_PWM0EN()    		PWM0CR&=~SET_BIT7
//#define SET_()	    	PWM0CR|=SET_BIT6					// PWM0CR^6;
//#define CLR_()	    	PWM0CR&=~SET_BIT6
#define SET_PWM0IF()   		PWM0CR|=SET_BIT5			// PWM0CR^5;
#define CLR_PWM0IF()   		PWM0CR&=~SET_BIT5
#define SET_PWM0OE()   		PWM0CR|=SET_BIT4			// PWM0CR^4;
#define CLR_PWM0OE()   		PWM0CR&=~SET_BIT4
#define SET_PWM0S()    		PWM0CR|=SET_BIT3			// PWM0CR^3;
#define CLR_PWM0S()    		PWM0CR&=~SET_BIT3
#define SET_PWM0C2()   		PWM0CR|=SET_BIT2			// PWM0CR^2;
#define CLR_PWM0C2()   		PWM0CR&=~SET_BIT2
#define SET_PWM0C1()   		PWM0CR|=SET_BIT1			// PWM0CR^1;
#define CLR_PWM0C1()   		PWM0CR&=~SET_BIT1
#define SET_PWM0C0()		PWM0CR|=SET_BIT0			// PWM0CR^0;
#define CLR_PWM0C0()		PWM0CR&=~SET_BIT0

/*  PWM0P, 0xDEH, SFR0  */

/*  PWM0D, 0xDFH, SFR0  */

/*  PWM1PH, 0xE1H, SFR1  */

/*  PWM1PL, 0xE2H, SFR1  */

/*  PWM1CR3, 0xE3H, SFR1  */
#define SET_PWM1CB()    	PWM1CR3|=SET_BIT7			// PWM1CR3^7;
#define CLR_PWM1CB()    	PWM1CR3&=~SET_BIT7
//#define SET_()	    	PWM1CR3|=SET_BIT6					// PWM1CR3^6;
//#define CLR_()	    	PWM1CR3&=~SET_BIT6
#define SET_PWM15B()   		PWM1CR3|=SET_BIT5			// PWM1CR3^5;
#define CLR_PWM15B()   		PWM1CR3&=~SET_BIT5
#define SET_PWM14B()   		PWM1CR3|=SET_BIT4			// PWM1CR3^4;
#define CLR_PWM14B()   		PWM1CR3&=~SET_BIT4
#define SET_PWM13B()   		PWM1CR3|=SET_BIT3			// PWM1CR3^3;
#define CLR_PWM13B()   		PWM1CR3&=~SET_BIT3
#define SET_PWM12B()   		PWM1CR3|=SET_BIT2			// PWM1CR3^2;
#define CLR_PWM12B()   		PWM1CR3&=~SET_BIT2
#define SET_PWM11B()   		PWM1CR3|=SET_BIT1			// PWM1CR3^1;
#define CLR_PWM11B()   		PWM1CR3&=~SET_BIT1
#define SET_PWM10B()		PWM1CR3|=SET_BIT0			// PWM1CR3^0;
#define CLR_PWM10B()		PWM1CR3&=~SET_BIT0

/*  PWM1CR2, 0xE4H, SFR1  */
#define SET_PWM1RL()    	PWM1CR2|=SET_BIT7			// PWM1CR2^7;
#define CLR_PWM1RL()    	PWM1CR2&=~SET_BIT7
#define SET_PWM145FEN()    	PWM1CR2|=SET_BIT6			// PWM1CR2^6;
#define CLR_PWM145FEN()    	PWM1CR2&=~SET_BIT6
#define SET_PWM123FEN()		PWM1CR2|=SET_BIT5			// PWM1CR2^5;
#define CLR_PWM123FEN()		PWM1CR2&=~SET_BIT5
#define SET_PWM101FEN()		PWM1CR2|=SET_BIT4			// PWM1CR2^4;
#define CLR_PWM101FEN()		PWM1CR2&=~SET_BIT4
//#define SET_()   		PWM1CR2|=SET_BIT3				// PWM1CR2^3;
//#define CLR_()   		PWM1CR2&=~SET_BIT3
#define SET_PWM145S()  		PWM1CR2|=SET_BIT2			// PWM1CR2^2;
#define CLR_PWM145S()  		PWM1CR2&=~SET_BIT2
#define SET_PWM123S()  		PWM1CR2|=SET_BIT1			// PWM1CR2^1;
#define CLR_PWM123S()  		PWM1CR2&=~SET_BIT1
#define SET_PWM101S()		PWM1CR2|=SET_BIT0			// PWM1CR2^0;
#define CLR_PWM101S()		PWM1CR2&=~SET_BIT0

/*  PWM1CR1, 0xE5H, SFR1  */
#define SET_PWM1CS()    	PWM1CR1|=SET_BIT7			// PWM1CR1^7;
#define CLR_PWM1CS()    	PWM1CR1&=~SET_BIT7
#define SET_PWM145MD()    	PWM1CR1|=SET_BIT6			// PWM1CR1^6;
#define CLR_PWM145MD()    	PWM1CR1&=~SET_BIT6
#define SET_PWM123MD() 		PWM1CR1|=SET_BIT5			// PWM1CR1^5;
#define CLR_PWM123MD() 		PWM1CR1&=~SET_BIT5
#define SET_PWM101MD() 		PWM1CR1|=SET_BIT4			// PWM1CR1^4;
#define CLR_PWM101MD() 		PWM1CR1&=~SET_BIT4
//#define SET_()  		PWM1CR1|=SET_BIT3					// PWM1CR1^3;
//#define CLR_()  		PWM1CR1&=~SET_BIT3
#define SET_PWM1CLK2() 		PWM1CR1|=SET_BIT2			// PWM1CR1^2;
#define CLR_PWM1CLK2() 		PWM1CR1&=~SET_BIT2
#define SET_PWM1CLK1() 		PWM1CR1|=SET_BIT1			// PWM1CR1^1;
#define CLR_PWM1CLK1() 		PWM1CR1&=~SET_BIT1
#define SET_PWM1CLK0()		PWM1CR1|=SET_BIT0			// PWM1CR1^0;
#define CLR_PWM1CLK0()		PWM1CR1&=~SET_BIT0

/*  PWM1CR0, 0xE6H, SFR1  */
#define SET_PWM1EN()    	PWM1CR0|=SET_BIT7			// PWM1CR0^7;
#define CLR_PWM1EN()    	PWM1CR0&=~SET_BIT7
//#define SET_()	    	PWM1CR0|=SET_BIT6					// PWM1CR0^6;
//#define CLR_()	    	PWM1CR0&=~SET_BIT6
#define SET_PWM15OE()  		PWM1CR0|=SET_BIT5			// PWM1CR0^5;
#define CLR_PWM15OE()  		PWM1CR0&=~SET_BIT5
#define SET_PWM14OE()  		PWM1CR0|=SET_BIT4			// PWM1CR0^4;
#define CLR_PWM14OE()  		PWM1CR0&=~SET_BIT4
#define SET_PWM13OE()  		PWM1CR0|=SET_BIT3			// PWM1CR0^3;
#define CLR_PWM13OE()  		PWM1CR0&=~SET_BIT3
#define SET_PWM12OE()  		PWM1CR0|=SET_BIT2			// PWM1CR0^2;
#define CLR_PWM12OE()  		PWM1CR0&=~SET_BIT2
#define SET_PWM11OE()  		PWM1CR0|=SET_BIT1			// PWM1CR0^1;
#define CLR_PWM11OE()  		PWM1CR0&=~SET_BIT1
#define SET_PWM10OE()		PWM1CR0|=SET_BIT0			// PWM1CR0^0;
#define CLR_PWM10OE()		PWM1CR0&=~SET_BIT0

/*  PWM1IER, 0xE7H, SFR1  */
#define SET_PWM1IF()    	PWM1IER|=SET_BIT7			// PWM1IER^7;
#define CLR_PWM1IF()    	PWM1IER&=~SET_BIT7
#define SET_PWM1FBIF()    	PWM1IER|=SET_BIT6			// PWM1IER^6;
#define CLR_PWM1FBIF()    	PWM1IER&=~SET_BIT6
//#define SET_()		 		PWM1IER|=SET_BIT5			// PWM1IER^5;
//#define CLR_()		  		PWM1IER&=~SET_BIT5
//#define SET_()		 		PWM1IER|=SET_BIT4			// PWM1IER^4;
//#define CLR_()		  		PWM1IER&=~SET_BIT4
//#define SET_()		 		PWM1IER|=SET_BIT3			// PWM1IER^3;
//#define CLR_()		  		PWM1IER&=~SET_BIT3
//#define SET_()		 		PWM1IER|=SET_BIT2			// PWM1IER^2;
//#define CLR_()		  		PWM1IER&=~SET_BIT2
#define SET_PWM1FBIS() 		PWM1IER|=SET_BIT1			// PWM1IER^1;
#define CLR_PWM1FBIS() 		PWM1IER&=~SET_BIT1
#define SET_PWM1FBEN()		PWM1IER|=SET_BIT0			// PWM1IER^0;
#define CLR_PWM1FBEN()		PWM1IER&=~SET_BIT0

/*  IAPCR, 0xE9H, SFR0  */
#define SET_IAPSTR()    	IAPCR|=SET_BIT7				// PWM1IER^7;
#define CLR_IAPSTR()    	IAPCR&=~SET_BIT7
//#define SET_()			    	IAPCR|=SET_BIT6				// PWM1IER^6;
//#define CLR_()    			IAPCR&=~SET_BIT6
//#define SET_() 				IAPCR|=SET_BIT5				// PWM1IER^5;
//#define CLR_()  				IAPCR&=~SET_BIT5
//#define SET_() 				IAPCR|=SET_BIT4				// PWM1IER^4;
//#define CLR_()  				IAPCR&=~SET_BIT4
#define SET_IAPTRIG2() 		IAPCR|=SET_BIT3				// PWM1IER^3;
#define CLR_IAPTRIG2() 		IAPCR&=~SET_BIT3
#define SET_IAPTRIG1() 		IAPCR|=SET_BIT2				// PWM1IER^2;
#define CLR_IAPTRIG1() 		IAPCR&=~SET_BIT2
#define SET_IAPTRIG0() 		IAPCR|=SET_BIT1				// PWM1IER^2;
#define CLR_IAPTRIG0() 		IAPCR&=~SET_BIT1
#define SET_EERD()			IAPCR|=SET_BIT0				// PWM1IER^0;
#define CLR_EERD()			IAPCR&=~SET_BIT0

/*  PWM12DH, 0xE9H, SFR1  */

/*  IAPADL, 0xEAH, SFR0  */

/*  PWM12DL, 0xEAH, SFR1  */

/*  IAPADH, 0xEBH, SFR0  */

/*  PWM101F, 0xEBH, SFR1  */

/*  IAPDB, 0xECH, SFR0  */

/*  PWM11DH, 0xECH, SFR1  */

/*  PWM11DL, 0xEDH, SFR1  */

/*  IAPMD, 0xEEH, SFR0  */
#define SET_IAPEN()			IAPMD|=SET_BIT7			// IAPMD^7;
#define CLR_IAPEN()			IAPMD&=~SET_BIT7
// #define SET_				|=SET_BIT6				// IAPMD^6;
// #define CLR_				&=~SET_BIT6
// #define SET_				|=SET_BIT5				// IAPMD^5;
// #define CLR_				&=~SET_BIT5
// #define SET_				|=SET_BIT4				// IAPMD^4;
// #define CLR_				&=~SET_BIT4
#define SET_ECHIPERS()		IAPMD|=SET_BIT3			// IAPMD^3;
#define CLR_ECHIPERS()		IAPMD&=~SET_BIT3
#define SET_EPAGEERS()		IAPMD|=SET_BIT2			// IAPMD^2;
#define CLR_EPAGEERS()		IAPMD&=~SET_BIT2
#define SET_EPAGEWR()		IAPMD|=SET_BIT1			// IAPMD^1;
#define CLR_EPAGEWR()		IAPMD&=~SET_BIT1
// #define SET_				|=SET_BIT0				// IAPMD^0;
// #define CLR_				&=~SET_BIT0

/*  PWM10DH, 0xEEH, SFR1  */

/*  IAPKEY, 0xEFH, SFR0  */

/*  PWM10DL, 0xEFH, SFR1  */

/*  AUXC, 0xF1H, SFR0  */

/*  PWM15DH, 0xF1H, SFR1  */

/*  PWM15DL, 0xF2H, SFR1  */

/*  PWM14DH, 0xF3H, SFR1  */

/*  PWM14DL, 0xF4H, SFR1  */

/*  PWM123F, 0xF5H, SFR1  */

/*  PWM13DH, 0xF6H, SFR1  */

/*  PWM13DL, 0xF7H, SFR1  */

/*  PWRCR, 0xF8H, SFR0  */

#define SET_PWM1_CLKEN()		PWRCR|=SET_BIT5			// ADCCR0^5;
#define CLR_PWM1_CLKEN()		PWRCR&=~SET_BIT5
#define SET_PWM0_CLKEN()		PWRCR|=SET_BIT4			// ADCCR0^4;
#define CLR_PWM0_CLKEN()		PWRCR&=~SET_BIT4
#define SET_SPI_CLKEN()			PWRCR|=SET_BIT3			// ADCCR0^3;
#define CLR_SPI_CLKEN()			PWRCR&=~SET_BIT3
#define SET_ADC_CLKEN()			PWRCR|=SET_BIT2			// ADCCR0^2;
#define CLR_ADC_CLKEN()			PWRCR&=~SET_BIT2
#define SET_LCD_CLKEN()			PWRCR|=SET_BIT1			// ADCCR0^1;
#define CLR_LCD_CLKEN()			PWRCR&=~SET_BIT1
#define SET_OCD_CLKEN()			PWRCR|=SET_BIT0			// ADCCR0^0;
#define CLR_OCD_CLKEN()			PWRCR&=~SET_BIT0

/*  PWRCR1, 0xF9H, SFR1  */
#define SET_TK_CLKEN()		PWRCR1|=SET_BIT7			// ADCCR0^7;
#define CLR_TK_CLKEN()		PWRCR1&=~SET_BIT7
#define SET_IIC_CLKEN()	  PWRCR1|=SET_BIT6			// ADCCR0^6;
#define CLR_IIC_CLKEN()	  PWRCR1&=~SET_BIT6
#define SET_CRC_CLKEN()		PWRCR1|=SET_BIT5			// ADCCR0^5;
#define CLR_CRC_CLKEN()		PWRCR1&=~SET_BIT5
#define SET_T3_CLKEN()	  PWRCR1|=SET_BIT2			// ADCCR0^2;
#define CLR_T3_CLKEN()	  PWRCR1&=~SET_BIT2
#define SET_T2_CLKEN()		PWRCR1|=SET_BIT1			// ADCCR0^1;
#define CLR_T2_CLKEN()		PWRCR1&=~SET_BIT1
#define SET_T01_CLKEN()		PWRCR1|=SET_BIT0			// ADCCR0^0;
#define CLR_T01_CLKEN()		PWRCR1&=~SET_BIT0
/*  ADCCR0, 0xF9H, SFR0  */
#define SET_ADCHS3()		ADCCR0|=SET_BIT7			// ADCCR0^7;
#define CLR_ADCHS3()		ADCCR0&=~SET_BIT7
#define SET_ADCHS2()	    ADCCR0|=SET_BIT6			// ADCCR0^6;
#define CLR_ADCHS2()	    ADCCR0&=~SET_BIT6
#define SET_ADCHS1()		ADCCR0|=SET_BIT5			// ADCCR0^5;
#define CLR_ADCHS1()		ADCCR0&=~SET_BIT5
#define SET_ADCHS0()		ADCCR0|=SET_BIT4			// ADCCR0^4;
#define CLR_ADCHS0()		ADCCR0&=~SET_BIT4
#define SET_VRS1()			ADCCR0|=SET_BIT3			// ADCCR0^3;
#define CLR_VRS1()			ADCCR0&=~SET_BIT3
#define SET_VRS0()			ADCCR0|=SET_BIT2			// ADCCR0^2;
#define CLR_VRS0()			ADCCR0&=~SET_BIT2
#define SET_ADEOC()			ADCCR0|=SET_BIT1			// ADCCR0^1;
#define CLR_ADEOC()			ADCCR0&=~SET_BIT1
#define SET_ADEN()			ADCCR0|=SET_BIT0			// ADCCR0^0;
#define CLR_ADEN()			ADCCR0&=~SET_BIT0

/*  ADCCR1, 0xFAH, SFR0  */
#define SET_ADRSEL()		ADCCR1|=SET_BIT7			// ADCCR1^7;
#define CLR_ADRSEL()		ADCCR1&=~SET_BIT7
#define SET_ADCKS2()	    ADCCR1|=SET_BIT6			// ADCCR1^6;
#define CLR_ADCKS2()	    ADCCR1&=~SET_BIT6
#define SET_ADCKS1()		ADCCR1|=SET_BIT5			// ADCCR1^5;
#define CLR_ADCKS1()		ADCCR1&=~SET_BIT5
#define SET_ADCKS0()		ADCCR1|=SET_BIT4			// ADCCR1^4;
#define CLR_ADCKS0()		ADCCR1&=~SET_BIT4
#define SET_ADSPS3()		ADCCR1|=SET_BIT3			// ADCCR1^3;
#define CLR_ADSPS3()		ADCCR1&=~SET_BIT3
#define SET_ADSPS2()		ADCCR1|=SET_BIT2			// ADCCR1^2;
#define CLR_ADSPS2()		ADCCR1&=~SET_BIT2
#define SET_ADSPS1()		ADCCR1|=SET_BIT1			// ADCCR1^1;
#define CLR_ADSPS1()		ADCCR1&=~SET_BIT1
#define SET_ADSPS0()		ADCCR1|=SET_BIT0			// ADCCR1^0;
#define CLR_ADSPS0()		ADCCR1&=~SET_BIT0

/*  ADRIOS0, 0xFBH, SFR0  */
#define SET_AN7EN()			ADRIOS0|=SET_BIT7			// ADRIOS0^7;
#define CLR_AN7EN()			ADRIOS0&=~SET_BIT7
#define SET_AN6EN()	    	ADRIOS0|=SET_BIT6			// ADRIOS0^6;
#define CLR_AN6EN()	    	ADRIOS0&=~SET_BIT6
#define SET_AN5EN()			ADRIOS0|=SET_BIT5			// ADRIOS0^5;
#define CLR_AN5EN()			ADRIOS0&=~SET_BIT5
#define SET_AN4EN()			ADRIOS0|=SET_BIT4			// ADRIOS0^4;
#define CLR_AN4EN()			ADRIOS0&=~SET_BIT4
#define SET_AN3EN()			ADRIOS0|=SET_BIT3			// ADRIOS0^3;
#define CLR_AN3EN()			ADRIOS0&=~SET_BIT3
#define SET_AN2EN()			ADRIOS0|=SET_BIT2			// ADRIOS0^2;
#define CLR_AN2EN()			ADRIOS0&=~SET_BIT2
#define SET_AN1EN()			ADRIOS0|=SET_BIT1			// ADRIOS0^1;
#define CLR_AN1EN()			ADRIOS0&=~SET_BIT1
#define SET_AN0EN()			ADRIOS0|=SET_BIT0			// ADRIOS0^0;
#define CLR_AN0EN()			ADRIOS0&=~SET_BIT0
	
/*  ADRIOS1, 0xFCH, SFR0  */
//#define SET_()		ADRIOS1|=SET_BIT7					// ADRIOS0^7;
//#define CLR_()		ADRIOS1&=~SET_BIT7
//#define SET_()	    	ADRIOS1|=SET_BIT6					// ADRIOS0^6;
//#define CLR_()	    	ADRIOS1&=~SET_BIT6
#define SET_EX_VREF_EN()	ADRIOS1|=SET_BIT5			// ADRIOS0^5;
#define CLR_EX_VREF_EN()	ADRIOS1&=~SET_BIT5
//#define SET_()		ADRIOS1|=SET_BIT4					// ADRIOS0^4;
//#define CLR_()		ADRIOS1&=~SET_BIT4
#define SET_AN11EN()		ADRIOS1|=SET_BIT3					// ADRIOS0^3;
#define CLR_AN11EN()		ADRIOS1&=~SET_BIT3
#define SET_AN10EN()		ADRIOS1|=SET_BIT2					// ADRIOS0^2;
#define CLR_AN10EN()		ADRIOS1&=~SET_BIT2
#define SET_AN9EN()			ADRIOS1|=SET_BIT1			// ADRIOS0^1;
#define CLR_AN9EN()			ADRIOS1&=~SET_BIT1
#define SET_AN8EN()			ADRIOS1|=SET_BIT0			// ADRIOS0^0;
#define CLR_AN8EN()			ADRIOS1&=~SET_BIT0

/*  ADRL, 0xFDH, SFR0  */

/*  ADRH, 0xFEH, SFR0  */

/*  OSADJCR, 0xFFH, SFR0  */
#define SET_OSADJEN()		OSADJCR|=SET_BIT7			// OSADJCR^7;
#define CLR_OSADJEN()		OSADJCR&=~SET_BIT7
//#define SET_()	    	OSADJCR|=SET_BIT6					// OSADJCR^6;
//#define CLR_()	    	OSADJCR&=~SET_BIT6
//#define SET_()		OSADJCR|=SET_BIT5					// OSADJCR^5;
//#define CLR_()		OSADJCR&=~SET_BIT5
#define SET_OSADJTR4()		OSADJCR|=SET_BIT4			// OSADJCR^4;
#define CLR_OSADJTR4()		OSADJCR&=~SET_BIT4
#define SET_OSADJTR3()		OSADJCR|=SET_BIT3			// OSADJCR^3;
#define CLR_OSADJTR3()		OSADJCR&=~SET_BIT3
#define SET_OSADJTR2()		OSADJCR|=SET_BIT2			// OSADJCR^2;
#define CLR_OSADJTR2()		OSADJCR&=~SET_BIT2
#define SET_OSADJTR1()		OSADJCR|=SET_BIT1			// OSADJCR^1;
#define CLR_OSADJTR1()		OSADJCR&=~SET_BIT1
#define SET_OSADJTR0()		OSADJCR|=SET_BIT0			// OSADJCR^0;
#define CLR_OSADJTR0()		OSADJCR&=~SET_BIT0

/*  PWM145F, 0xFFH, SFR1  */
//#endif

#endif /* __MC51F8124_COMMON_H_ */

/********************************************************************
* End of file
********************************************************************/
